@@ -62,7 +62,7 @@ G_BEGIN_DECLS
 #define VTE_COLOR_DIM_OFFSET		16
 /* More color defines in ring.h */
 
-#define VTE_SCROLLBACK_INIT		100
+#define VTE_SCROLLBACK_INIT		512
 #define VTE_SATURATION_MAX		10000
 #define VTE_DEFAULT_CURSOR		GDK_XTERM
 #define VTE_MOUSING_CURSOR		GDK_LEFT_PTR
@@ -143,10 +143,6 @@ typedef struct _VteWordCharRange {
 	gunichar start, end;
 } VteWordCharRange;
 
-typedef struct _VteVisualPosition {
-	long row, col;
-} VteVisualPosition;
-
 /* Terminal private data. */
 struct _VteTerminalPrivate {
 	/* Emulation setup data. */
@@ -274,7 +270,7 @@ struct _VteTerminalPrivate {
 	guint bell_margin;
 	gboolean allow_bold;
 	gboolean nrc_mode;
-	gboolean smooth_scroll;
+        gboolean deccolm_mode; /* DECCOLM allowed */
 	GHashTable *tabstops;
 	gboolean text_modified_flag;
 	gboolean text_inserted_flag;
@@ -284,6 +280,7 @@ struct _VteTerminalPrivate {
 	gboolean scroll_background;
 	gboolean scroll_on_output;
 	gboolean scroll_on_keystroke;
+	gboolean alternate_screen_scroll;
 	long scrollback_lines;
 
 	/* Cursor shape */
@@ -312,6 +309,7 @@ struct _VteTerminalPrivate {
 	guint mouse_autoscroll_tag;
 	gboolean mouse_xterm_extension;
 	gboolean mouse_urxvt_extension;
+	double mouse_smooth_scroll_delta;
 
 	/* State variables for handling match checks. */
 	char *match_contents;
@@ -341,8 +339,10 @@ struct _VteTerminalPrivate {
 
 	gboolean palette_initialized;
 	gboolean highlight_color_set;
+	gboolean cursor_default_color_set;
 	gboolean cursor_color_set;
-	PangoColor palette[VTE_PALETTE_SIZE];
+	PangoColor default_palette[VTE_PALETTE_SIZE];  /* get/set via API calls */
+	PangoColor palette[VTE_PALETTE_SIZE];  /* get/set via escape sequences */
 
 	/* Mouse cursors. */
 	gboolean mouse_cursor_visible;
@@ -444,7 +444,11 @@ void _vte_terminal_visible_beep(VteTerminal *terminal);
 void _vte_terminal_beep(VteTerminal *terminal);
 void _vte_terminal_set_color_internal(VteTerminal *terminal,
                                       int idx,
+                                      gboolean via_escape,
                                       const GdkColor *color);
+void _vte_terminal_set_color_cursor_internal(VteTerminal *terminal,
+                                             gboolean via_escape,
+                                             const GdkColor *color);
 
 void _vte_terminal_inline_error_message(VteTerminal *terminal, const char *format, ...) G_GNUC_PRINTF(2,3);
 
